@@ -268,6 +268,7 @@ cspi_object_borrow (CORBA_Object corba_object)
 void
 cspi_object_return (Accessible *accessible)
 {
+  int old_ref_count;
   g_return_if_fail (accessible != NULL);
 
   if (!accessible->on_loan ||
@@ -278,8 +279,17 @@ cspi_object_return (Accessible *accessible)
   else /* Convert to a permanant ref */
     {
       accessible->on_loan = FALSE;
+      old_ref_count = accessible->ref_count;
       accessible->objref = cspi_dup_ref (accessible->objref);
-      accessible->ref_count--;
+      if (old_ref_count != accessible->ref_count &&
+          accessible->ref_count == 1)
+        {
+            cspi_object_unref (accessible);
+        }
+      else    
+        {
+          accessible->ref_count--;
+        }
     }
 }
 
@@ -485,9 +495,14 @@ SPI_exit (void)
   if (live_refs)
     {
       leaked = g_hash_table_size (live_refs);
+#ifdef DEBUG_OBJECTS
+      fprintf (stderr, "Leaked %d SPI handles\n", leaked);
+
 #define PRINT_LEAKS
 #ifdef PRINT_LEAKS
       g_hash_table_foreach (live_refs, report_leaked_ref, NULL);
+#endif
+
 #endif
     }
   else
@@ -495,17 +510,8 @@ SPI_exit (void)
       leaked = 0;
     }
 
-#ifdef DEBUG_OBJECTS
-  if (leaked)
-    {
-      fprintf (stderr, "Leaked %d SPI handles\n", leaked);
-    }
-#endif
-
   cspi_cleanup ();
 
-  fprintf (stderr, "bye-bye!\n");
-
   return leaked;
 }
 
@@ -569,7 +575,7 @@ SPIExceptionType SPIException_getSourceType (SPIException *err)
   if (err)
     return err->type;
   else
-    return SPI_EXCEPTION_UNSPECIFIED;
+    return SPI_EXCEPTION_SOURCE_UNSPECIFIED;
 }
 
 /**
